==> haskell-unix-time-0.4.16-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-time
version:              0.4.16
visibility:           public
id:                   unix-time-0.4.16-KYZiiH0xpEz7CP5irPbvd8
key:                  unix-time-0.4.16-KYZiiH0xpEz7CP5irPbvd8
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Unix time parser/formatter and utilities
description:          Fast parser\/formatter\/utilities for Unix time
category:             Data
abi:                  af7926a5f1eb5c8aa9f0c89cf33f0e56
exposed:              True
exposed-modules:      Data.UnixTime
hidden-modules:
    Data.UnixTime.Conv Data.UnixTime.Diff Data.UnixTime.Types
    Data.UnixTime.Sys

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-time
hs-libraries:         HSunix-time-0.4.16-KYZiiH0xpEz7CP5irPbvd8
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9

haddock-interfaces:   /usr/share/doc/haskell-unix-time/html/unix-time.haddock
haddock-html:         /usr/share/doc/haskell-unix-time/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-time-0.4.16-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-time
version:              0.4.16
visibility:           public
id:                   unix-time-0.4.16-BCqqIe3YZGw5RJU9HOvPZU
key:                  unix-time-0.4.16-BCqqIe3YZGw5RJU9HOvPZU
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Unix time parser/formatter and utilities
description:          Fast parser\/formatter\/utilities for Unix time
category:             Data
abi:                  01efbd462fb5b39f1c6a822bdf0098e3
exposed:              True
exposed-modules:      Data.UnixTime
hidden-modules:
    Data.UnixTime.Conv Data.UnixTime.Diff Data.UnixTime.Types
    Data.UnixTime.Sys

import-dirs:          /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/unix-time-0.4.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-time
hs-libraries:         HSunix-time-0.4.16-BCqqIe3YZGw5RJU9HOvPZU
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9

haddock-interfaces:   /usr/share/doc/haskell-unix-time/html/unix-time.haddock
haddock-html:         /usr/share/doc/haskell-unix-time/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
